﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;


using Autodesk.Navisworks.Api;
using Autodesk.Navisworks.Api.Plugins;

namespace DevTV_Navisworks_Plugins
{
    #region "插件系统"
    [PluginAttribute("DevTV_Plugin_System", //插件内部名         
                "ADSK",  // 开发者号  4位         
                ToolTip = "插件系统测试",//提示         
                DisplayName = "DevTV_Plugin_System")]  //显示在用户界面上的名字

    // 放置位置 
    [AddInPlugin(AddInLocation.AddIn )]
    class class_Plugin_System : AddInPlugin
    {
        public override int Execute(params string[] parameters)
        {
            StringBuilder plugins = new StringBuilder();

            //iterate the plugins and display a list in a message box
            if (Autodesk.Navisworks.Api.Application.Plugins != null &&
               Autodesk.Navisworks.Api.Application.Plugins.PluginRecords != null)
            {
                foreach (Autodesk.Navisworks.Api.Plugins.PluginRecord pr in
                   Autodesk.Navisworks.Api.Application.Plugins.PluginRecords)
                {
                    //Append the plugin Information
                    plugins.Append("Id = ");
                    plugins.Append(pr.Id);
                    plugins.Append(", Type = ");
                    plugins.Append(pr.GetType().ToString());
                    plugins.Append(", DeveloperId = ");
                    plugins.Append(pr.DeveloperId);
                    plugins.Append(", DisplayName = ");
                    plugins.Append(pr.DisplayName);
                    plugins.Append(", IsEnabled = ");
                    plugins.Append(pr.IsEnabled);
                    plugins.Append(", IsLoaded = ");
                    plugins.Append(pr.IsLoaded);
                    plugins.Append(", Name = ");
                    plugins.Append(pr.Name);
                    plugins.Append(", PluginOptions = ");
                    plugins.Append(pr.PluginOptions.ToString());
                    plugins.Append(", ToolTip = ");
                    plugins.Append(pr.ToolTip);

                    plugins.AppendLine();
                }
                //show the list of plugins
                MessageBox.Show(plugins.ToString());
            }

            return 0;
        }
    }
    #endregion


    #region "执行另外的插件"
    [PluginAttribute("DevTV_Execute_Others", //插件内部名         
                "ADSK",  // 开发者号  4位         
                ToolTip = "执行另外的插件",//提示         
                DisplayName = "DevTV_Execute_Others")]  //显示在用户界面上的名字

    // 放置位置 
    [AddInPlugin(AddInLocation.AddIn)]
    class class_Execute_Others : AddInPlugin
    {
        public override int Execute(params string[] parameters)
        {

            //executeDockPane();

            executeCustomPlugin();
            return 0;
        }

        private void executeDockPane()
        {
            try
            {
                //查找是否有名为  "DevTV_DockPanePlugin.ADSK 的插件
                PluginRecord pr =
                    Autodesk.Navisworks.Api.Application.Plugins.FindPlugin("DevTV_DockPanePlugin.ADSK");
                if (pr != null)
                {
                    //加载此插件
                    if (!pr.IsLoaded)
                        pr.LoadPlugin();

                    //如果是一个DockPanePlugin
                    DockPanePlugin oDockPlugin = (DockPanePlugin)pr.LoadedPlugin;
                    //打开或关闭停靠窗口
                    if(oDockPlugin != null)
                       oDockPlugin.Visible = !oDockPlugin.Visible;
                } 

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }

        private void executeCustomPlugin()
        {
            try
            {
                //查询是否有名为DevTV_CustomPlugin.ADSK的插件
                PluginRecord pr =
                   Autodesk.Navisworks.Api.Application.Plugins.FindPlugin("DevTV_CustomPlugin.ADSK");
                if (pr != null)
                {
                    if (!pr.IsLoaded)
                        pr.LoadPlugin();

                    class_CustomPlugin oMyPlugin = (class_CustomPlugin)pr.LoadedPlugin;
                    MessageBox.Show(oMyPlugin.calculate(3, 5).ToString());

                    Autodesk.Navisworks.Api.Color oColor = new Autodesk.Navisworks.Api.Color(1, 0, 0);
                    Document oDoc = Autodesk.Navisworks.Api.Application.ActiveDocument;
                    oMyPlugin.override_color(oDoc.CurrentSelection.SelectedItems, oColor);

                }


            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }
    }
    #endregion
}
